pub unsafe extern "C" fn async_acquire_shared_ref(
dispatcher: *mut async_dispatcher_t,
) -> zx_status_tExpand description
If supported, acquires a shared dispatcher reference for this dispatcher.
If successful, the internal reference count of the dispatcher object will be incremented so that it will not be deallocated for any other reason than the outstanding refcount reaching zero. If it fails there will be no guarantees about the lifetime of the dispatcher object.
Note that this will not prevent the dispatcher from shutting down. Calls to dispatcher methods after shutting down will behave as if the dispatcher is still shutting down.
The client MUST call |async_release_shared_ref| on the returned pointer when it is no longer in use if this call succeeds. Not doing so will result in memory leaks.
Returns |ZX_OK| if a shared dispatcher object’s reference count has been incremented and its memory won’t be released before you have called a corresponding |async_release_shared_ref|. Returns |ZX_ERR_NOT_SUPPORTED| if not supported by the dispatcher.
This operation is thread-safe.