pub unsafe extern "C" fn async_begin_wait(
dispatcher: *mut async_dispatcher_t,
wait: *mut async_wait_t,
) -> zx_status_tExpand description
Begins asynchronously waiting for an object to receive one or more signals specified in |wait|. Invokes the handler when the wait completes.
The wait’s handler will be invoked exactly once unless the wait is canceled. When the dispatcher is shutting down (being destroyed), the handlers of all remaining waits will be invoked with a status of |ZX_ERR_CANCELED|.
Returns |ZX_OK| if the wait was successfully begun. Returns |ZX_ERR_ACCESS_DENIED| if the object does not have |ZX_RIGHT_WAIT|. Returns |ZX_ERR_BAD_STATE| if the dispatcher is shutting down. Returns |ZX_ERR_NOT_SUPPORTED| if not supported by the dispatcher.
This operation is thread-safe.