async_cancel_wait

Function async_cancel_wait 

pub unsafe extern "C" fn async_cancel_wait(
    dispatcher: *mut async_dispatcher_t,
    wait: *mut async_wait_t,
) -> zx_status_t
Cancels the wait associated with |wait|.

If successful, the wait’s handler will not run.

Returns |ZX_OK| if the wait was pending and it has been successfully canceled; its handler will not run again and can be released immediately. Returns |ZX_ERR_NOT_FOUND| if there was no pending wait either because it already completed, had not been started, or its completion packet has been dequeued from the port and is pending delivery to its handler (perhaps on another thread). Returns |ZX_ERR_NOT_SUPPORTED| if not supported by the dispatcher.

This operation is thread-safe.