pub unsafe extern "C" fn async_detach_paged_vmo(
dispatcher: *mut async_dispatcher_t,
paged_vmo: *mut async_paged_vmo_t,
) -> zx_status_tExpand description
Detach ownership of VMO from pager.
Returns |ZX_ERR_NOT_SUPPORTED| if not supported by the dispatcher. Returns |ZX_ERR_BAD_HANDLE| if pager or vmo is not a valid handle. Returns |ZX_ERR_WRONG_TYPE| if pager is not a pager handle or vmo is not a vmo handle. Returns |ZX_ERR_INVALID_ARGS| if vmo is not a vmo created from pager. Other error values are possible. See the documentation for |zx_detach_paged_vmo()|.