pub extern "C" fn async_get_default_dispatcher() -> *const async_dispatcher_tExpand description
Gets the currently active async dispatcher for the current thread, if set.
pub extern "C" fn async_get_default_dispatcher() -> *const async_dispatcher_tGets the currently active async dispatcher for the current thread, if set.