pub unsafe extern "C" fn async_get_sequence_id(
dispatcher: *mut async_dispatcher_t,
out_sequence_id: *mut async_sequence_id_t,
out_error: *mut *const c_char,
) -> zx_status_tExpand description
Gets the dispatcher-specific sequence identifier of the currently executing task.
If the execution context of the calling thread is associated with a sequence, the dispatcher should populate the sequence identifier representing the current sequence. Otherwise, it should return an error code detailed below.
Returns |ZX_OK| if the sequence identifier was successfully obtained. Returns |ZX_ERR_INVALID_ARGS| if the dispatcher supports sequences, but the calling thread is not executing a task managed by the dispatcher. Returns |ZX_ERR_WRONG_TYPE| if the calling thread is executing a task managed by the dispatcher, but that task is not part of a sequence. Returns |ZX_ERR_NOT_SUPPORTED| if not supported by the dispatcher.
|out_error| will not be mutated when the return value is |ZX_OK|. Otherwise, it will be set to a NULL-terminated detailed explanation of the error, which may suggest corrective actions that are specific to that asynchronous runtime. If set, the error string will have static storage duration (for example, an implementation may return string literals).
This operation is thread-safe.