async_release_shared_ref

Function async_release_shared_ref 

pub unsafe extern "C" fn async_release_shared_ref(
    dispatcher: *mut async_dispatcher_t,
) -> zx_status_t
Releases a shared dispatcher reference for this dispatcher.

The caller must call this to release a shared dispatcher object acquired by |async_acquire_shared_ref|. In general, this should always return ZX_OK if the api is used correctly.

Returns |ZX_OK| if the dispatcher has been successfully released. Returns |ZX_ERR_NOT_SUPPORTED| if you have tried to call this on a dispatcher that does not support having shared references.