async_paged_vmo

Struct async_paged_vmo 

#[repr(C)]
pub struct async_paged_vmo { pub state: async_state_t, pub handler: async_paged_vmo_handler_t, pub pager: zx_handle_t, pub vmo: zx_handle_t, }
Holds content for a paged request packet receiver and its handler.

The client is responsible for retaining the structure in memory (and unmodified) until all packets have been received by the handler or the dispatcher shuts down.

Fields

state: async_state_t

Private state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.

handler: async_paged_vmo_handler_t

The handler to invoke when a packet is received.

pager: zx_handle_t

The associated pager when creating the VMO.

vmo: zx_handle_t

The VMO for this request.