pub type async_guest_bell_trap_t = async_guest_bell_trap;Expand description
Holds context for a bell trap and its handler.
After successfully posting setting the trap, the client is responsible for retaining the structure in memory (and unmodified) until the guest has been destroyed or the dispatcher shuts down. There is no way to cancel a trap which has been set.
Aliased Type
#[repr(C)]pub struct async_guest_bell_trap_t {
pub state: async_state_t,
pub handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_guest_bell_trap, i32, *const zx_packet_guest_bell_t)>,
}Fields
state: async_state_tPrivate state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.
handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_guest_bell_trap, i32, *const zx_packet_guest_bell_t)>The handler to invoke to handle the trap access.