async_paged_vmo_t

Type Alias async_paged_vmo_t 

pub type async_paged_vmo_t = async_paged_vmo;
Holds content for a paged request packet receiver and its handler.

The client is responsible for retaining the structure in memory (and unmodified) until all packets have been received by the handler or the dispatcher shuts down.

Aliased Type

#[repr(C)]
pub struct async_paged_vmo_t { pub state: async_state_t, pub handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_paged_vmo, i32, *const zx_packet_page_request_t)>, pub pager: u32, pub vmo: u32, }

Fields

state: async_state_t

Private state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.

handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_paged_vmo, i32, *const zx_packet_page_request_t)>

The handler to invoke when a packet is received.

pager: u32

The associated pager when creating the VMO.

vmo: u32

The VMO for this request.