pub type async_receiver_t = async_receiver;Expand description
Holds content for a packet receiver and its handler.
After successfully queuing packets to the receiver, the client is responsible for retaining the structure in memory (and unmodified) until all packets have been received by the handler or the dispatcher shuts down. There is no way to cancel a packet which has been queued.
Multiple packets may be delivered to the same receiver concurrently.
Aliased Type
#[repr(C)]pub struct async_receiver_t {
pub state: async_state_t,
pub handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_receiver, i32, *const [u8; 32])>,
}Fields
state: async_state_tPrivate state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.
handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_receiver, i32, *const [u8; 32])>The handler to invoke when a packet is received.