pub type async_wait_t = async_wait;Expand description
Holds context for an asynchronous wait operation and its handler.
After successfully beginning the wait, the client is responsible for retaining the structure in memory (and unmodified) until the wait’s handler runs, the wait is successfully canceled, or the dispatcher shuts down. Thereafter, the wait may be started begun or destroyed.
Aliased Type
#[repr(C)]pub struct async_wait_t {
pub state: async_state_t,
pub handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_wait, i32, *const zx_packet_signal_t)>,
pub object: u32,
pub trigger: u32,
pub options: u32,
}Fields
state: async_state_tPrivate state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.
handler: Option<unsafe extern "C" fn(*mut async_dispatcher, *mut async_wait, i32, *const zx_packet_signal_t)>The wait’s handler function.
object: u32The object to wait for signals on.
trigger: u32The set of signals to wait for.
options: u32Wait options, see zx_object_wait_async().