pub unsafe extern "C" fn async_now(
dispatcher: *mut async_dispatcher_t,
) -> zx_time_tExpand description
Returns the current time in the dispatcher’s timebase. For most loops, this is generally obtained from |ZX_CLOCK_MONOTONIC| but certain loops may use a different tiembase, notably for testing.