pub unsafe extern "C" fn async_set_default_dispatcher(
dispatcher: *const async_dispatcher_t,
)Expand description
Sets the current thread’s default asynchronous dispatcher interface. May be set to |NULL| if this thread doesn’t have a default dispatcher.
Safety
The caller must ensure that the dispatcher being passed in is currently valid, and that it will remain valid until either the current thread has exited or it has been replaced with another dispatcher (including NULL).