#[repr(C)]pub struct async_guest_bell_trap {
pub state: async_state_t,
pub handler: async_guest_bell_trap_handler_t,
}Expand description
Holds context for a bell trap and its handler.
After successfully posting setting the trap, the client is responsible for retaining the structure in memory (and unmodified) until the guest has been destroyed or the dispatcher shuts down. There is no way to cancel a trap which has been set.
Fields
state: async_state_tPrivate state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.
handler: async_guest_bell_trap_handler_tThe handler to invoke to handle the trap access.