#[repr(C)]pub struct async_paged_vmo {
pub state: async_state_t,
pub handler: async_paged_vmo_handler_t,
pub pager: zx_handle_t,
pub vmo: zx_handle_t,
}Expand description
Holds content for a paged request packet receiver and its handler.
The client is responsible for retaining the structure in memory (and unmodified) until all packets have been received by the handler or the dispatcher shuts down.
Fields
state: async_state_tPrivate state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.
handler: async_paged_vmo_handler_tThe handler to invoke when a packet is received.
pager: zx_handle_tThe associated pager when creating the VMO.
vmo: zx_handle_tThe VMO for this request.