#[repr(C)]pub struct async_wait {
pub state: async_state_t,
pub handler: async_wait_handler_t,
pub object: zx_handle_t,
pub trigger: zx_signals_t,
pub options: u32,
}Expand description
Holds context for an asynchronous wait operation and its handler.
After successfully beginning the wait, the client is responsible for retaining the structure in memory (and unmodified) until the wait’s handler runs, the wait is successfully canceled, or the dispatcher shuts down. Thereafter, the wait may be started begun or destroyed.
Fields
state: async_state_tPrivate state owned by the dispatcher, initialize to zero with |ASYNC_STATE_INIT|.
handler: async_wait_handler_tThe wait’s handler function.
object: zx_handle_tThe object to wait for signals on.
trigger: zx_signals_tThe set of signals to wait for.
options: u32Wait options, see zx_object_wait_async().