pub type async_sequence_id_t = async_sequence_id;Expand description
A dispatcher-specific sequence identifier, which identifies a set of actions with a total ordering of execution: each subsequent action will always observe side-effects from previous actions, if the thread(s) performing those actions have the same sequence identifier.
For example, a dispatcher backed by a thread pool may choose to implement sequences by acquiring a sequence-specific lock before running any actions from that sequence, ensuring mutual exclusion within each sequence.
Aliased Type
#[repr(C)]pub struct async_sequence_id_t {
pub value: u64,
}Fields
value: u64